/**
  ******************************************************************************
  * @file    CRC_DMA/inc/main.h
  * @author  MCD Application Team
  * @version V1.0.1
  * @date    21-October-2013
  * @brief   Header for main.c module
  ******************************************************************************
  * @attention
  *
  * <h2><center>&copy; COPYRIGHT 2013 STMicroelectronics</center></h2>
  *
  * Licensed under MCD-ST Liberty SW License Agreement V2, (the "License");
  * You may not use this file except in compliance with the License.
  * You may obtain a copy of the License at:
  *
  *        http://www.st.com/software_license_agreement_liberty_v2
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  * See the License for the specific language governing permissions and
  * limitations under the License.
  *
  ******************************************************************************
  */

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef __MAIN_H
#define __MAIN_H

/* Includes ------------------------------------------------------------------*/
#if defined (STM32F10X_LD) || defined (STM32F10X_LD_VL) || \
  defined (STM32F10X_MD) || defined (STM32F10X_MD_VL) || \
  defined (STM32F10X_HD) || defined (STM32F10X_HD_VL) || \
  defined (STM32F10X_XL) || defined (STM32F10X_CL)
#include "stm32f10x.h" /* STM32F10X definitions */
#elif defined (STM32L1XX_MD) || defined (STM32L1XX_MDP) || \
   defined (STM32L1XX_HD)
#include "stm32l1xx.h" /* STM32L1XX definitions */
#elif defined (STM32F2XX)
#include "stm32f2xx.h" /* STM32F2XX definitions */
#elif defined (STM32F4XX)
#include "stm32f4xx.h" /* STM32F4XX definitions */
#elif defined (STM32F0XX)
#include "stm32f0xx.h" /* STM32F0XX definitions */
#elif defined (STM32F37X)
#include "stm32f37x.h" /* STM32F37X definitions */
#elif defined (STM32F30X)
#include "stm32f30x.h" /* STM32F30X definitions */
#endif
#include <stdio.h> /* prototype declarations for I/O functions */

/* Exported types ------------------------------------------------------------*/
/* Exported constants --------------------------------------------------------*/
#define SYSTICK_INIT_VALUE 0XFFFFFF
#define SYSTICK_MASK 5
/* Exported macro ------------------------------------------------------------*/
#define SYSTICK_STOP SysTick->CTRL  &= ~(0x1)
#define SYSTICK_RESET SysTick->CTRL = 0; \
  SysTick->VAL  = SYSTICK_INIT_VALUE; \
  SysTick->LOAD = SYSTICK_INIT_VALUE

#define SYSTICK_START SysTick->CTRL = SYSTICK_MASK
/* Exported functions ------------------------------------------------------- */

#if defined (STM32F37X) || defined (STM32F30X)
#if (CONFIGPOLYNOME == 16)
#define POLYSIZE CRC_PolSize_16
#define POLYRETURN uint16_t
#ifndef POLYNOME
#define POLYNOME 0x8810
#endif
#define DATA_LENGTH 16
#elif (CONFIGPOLYNOME == 8)
#define POLYSIZE CRC_PolSize_8
#define POLYRETURN uint8_t
#ifndef POLYNOME
#define POLYNOME 0xEB
#endif
#define DATA_LENGTH 8
#elif (CONFIGPOLYNOME == 7)
#define POLYSIZE CRC_PolSize_7
#define POLYRETURN uint8_t
#ifndef POLYNOME
#define POLYNOME 0x5B
#endif
#define DATA_LENGTH 8
#endif
#endif

#if !defined(CONFIGPOLYNOME) || (CONFIGPOLYNOME == 32)
#define POLYSIZE CRC_PolSize_32
#define POLYRETURN uint32_t
#ifndef POLYNOME
#define POLYNOME 0x04C11DB7
#endif
#define DATA_LENGTH 32
#endif

#if !defined(DATA_LENGTH) || (DATA_LENGTH == 32)
#define DATATYPE uint32_t
#define DMAPeripheralTransferSize DMA_PeripheralDataSize_Word
#define DMAMemoryTransferSize DMA_MemoryDataSize_Word
#elif (DATA_LENGTH == 16)
#define DATATYPE uint16_t
#define DMAPeripheralTransferSize DMA_PeripheralDataSize_HalfWord
#define DMAMemoryTransferSize DMA_MemoryDataSize_HalfWord
#elif (DATA_LENGTH == 8)
#define DATATYPE uint8_t
#define DMAPeripheralTransferSize DMA_PeripheralDataSize_Byte
#define DMAMemoryTransferSize DMA_MemoryDataSize_Byte
#endif

#if defined(STM32F2XX) || defined (STM32F4XX)
#define DMA_CHANNEL DMA_Channel_0
#define DMA_STREAM DMA2_Stream0
#define DMA_IRQ DMA2_Stream0_IRQn
#elif defined(STM32F0XX)
#define DMA_CHANNEL DMA1_Channel2
#define DMA_IRQ DMA1_Channel2_3_IRQn
#else
#define DMA_CHANNEL DMA1_Channel2
#define DMA_IRQ DMA1_Channel2_IRQn
#endif /* defined(STM32F2XX) || defined (STM32F4XX) */

#endif /* __MAIN_H */

/************************ (C) COPYRIGHT STMicroelectronics *****END OF FILE****/
