/**
  ******************************************************************************
  * @file    CRC_DMA/src/main.c
  * @author  MCD Application Team
  * @version V1.0.1
  * @date    21-October-2013
  * @brief   The main program of the CRC_DMA example
  ******************************************************************************
  * @attention
  *
  * <h2><center>&copy; COPYRIGHT 2013 STMicroelectronics</center></h2>
  *
  * Licensed under MCD-ST Liberty SW License Agreement V2, (the "License");
  * You may not use this file except in compliance with the License.
  * You may obtain a copy of the License at:
  *
  *        http://www.st.com/software_license_agreement_liberty_v2
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  * See the License for the specific language governing permissions and
  * limitations under the License.
  *
  ******************************************************************************
  */
/* Includes ------------------------------------------------------------------*/
#include "main.h"

/** @addtogroup AN4187 examples
  * @{
  */

/** @defgroup CRC_DMA example
  * @brief
  * @{
  */


/* External variables --------------------------------------------------------*/
/* Private typedef -----------------------------------------------------------*/
/* Private defines -----------------------------------------------------------*/
#define BUFFER_SIZE    8191 /* data buffer size */
#define LOWER 0 /* lower limit */
#define UPPER BUFFER_SIZE /* upper limit */
#define STEP 1 /* step size */
#define INITIAL_CRC_VALUE 0xFFFFFFFF /* Initial CRC Data register value */

/* Private macro -------------------------------------------------------------*/
/* Private variables ---------------------------------------------------------*/
__IO uint32_t ProcessTimeConfCRC = 0;
__IO uint32_t ProcessTimeConfDMA = 0;
__IO uint32_t ProcessTimeDMA = 0;
__IO uint32_t ProcessTimeCPU = 0;
__IO uint32_t ProcessTimeIRQDMA = 0;
__IO POLYRETURN CRCValue = 0;
__IO POLYRETURN ComputedCRCDMA = 0;

/* Private function prototypes -----------------------------------------------*/
POLYRETURN CRC_CalcBlockCRCxxbits(DATATYPE*);
void CRC_Enable(void);
void CRC_Config(void);
void CRC_DMA_Config(uint32_t);
/* Private functions ---------------------------------------------------------*/
/**
  * @brief  Main program.
  * @param  None
  * @retval None
  */
int main(void)
{
  /*!< At this stage the microcontroller clock setting is already configured,
        this is done through SystemInit() function which is called from startup
        file before to branch to application main.
        To reconfigure the default setting of SystemInit() function, refer to
        system_stm32fxxx.c file
      */
  /* Enable the CRC peripheral */
  CRC_Enable();
#if defined(STM32F37X) || defined(STM32F30X) || defined(STM32F0XX)
  /* CRC Enable clock and CRC configure */
  CRC_Config();
#endif /* defined(STM32F37X) || defined(STM32F30X) || defined(STM32F0XX) */

  /* Compute DataBuffer table CRC by the CRC Peripheral*/
  CRCValue = CRC_CalcBlockCRCxxbits((DATATYPE*)FLASH_BASE);

  /* Get the systick execution time of the CRC_CalcBlockCRCxxbits function*/
  ProcessTimeCPU = SYSTICK_INIT_VALUE - (SysTick->VAL);

  /* Reset the systick peripheral */
  SYSTICK_RESET;

  /* Set LOAD and CTRL registers of the Systick to the specified values */
  SYSTICK_START;

  /* Enable the CRC peripheral */
  CRC_Enable();

#if defined(STM32F37X) || defined(STM32F30X) || defined(STM32F0XX)
  /* CRC Enable clock and CRC configure */
  CRC_Config();
#else
  /* Reset CRC Data Register */
  CRC_ResetDR();
#endif /* defined(STM32F37X) || defined(STM32F30X) || defined(STM32F0XX) */

  /* Stop the Systick peripheral */
  SYSTICK_STOP;

  /* Get the systick execution time of the CRC Configuration*/
  ProcessTimeConfCRC = SYSTICK_INIT_VALUE - (SysTick->VAL);

  /* Reset the systick peripheral */
  SYSTICK_RESET;

  /* Set LOAD and CTRL registers of the Systick to the specified values */
  SYSTICK_START;

  /* Configure and run the CRC DMA transfer back to back mode */
  CRC_DMA_Config(FLASH_BASE);

  /* Stop the Systick peripheral */
  SYSTICK_STOP;

  /* Get the systick execution time of the CRC Configuration*/
  ProcessTimeConfDMA = SYSTICK_INIT_VALUE - (SysTick->VAL);

#if  defined(STM32F2XX) || defined (STM32F4XX)
  /* DMA Stream enable */
  DMA_Cmd(DMA_STREAM, ENABLE);
#else
  /* DMA Channel or Stream enable */
  DMA_Cmd(DMA_CHANNEL, ENABLE);
#endif /* defined(STM32F2XX) || defined (STM32F4XX) */

  /* Reset the systick peripheral */
  SYSTICK_RESET;

  /* Set LOAD and CTRL registers of the Systick to the specified values */
  SYSTICK_START;

  __WFE();
  while (1)
  {}
}

/**
 * @brief  Enable CRC peripheral
 * @param  None
 * @retval None
 */
void CRC_Enable(void)
{

  /* Enable CRC clock */
#if defined (STM32F2XX) || defined (STM32F4XX)
  RCC_AHB1PeriphClockCmd(RCC_AHB1Periph_CRC, ENABLE);
#else
  RCC_AHBPeriphClockCmd(RCC_AHBPeriph_CRC, ENABLE);
#endif /* defined (STM32F2XX) || defined (STM32F4XX) */
}

/**
 * @brief  Configure CRC peripheral
 * @param  None
 * @retval None
 */
void CRC_Config(void)
{

#if defined (STM32F30X) || defined (STM32F37X)
  /* DeInit CRC peripheral */
  CRC_DeInit();

  /* Init the INIT register */
  CRC_SetInitRegister(INITIAL_CRC_VALUE);

  /* Select 8-bit polynomial size */
  CRC_PolynomialSizeSelect(POLYSIZE);

  /* Set the polynomial coefficients */
  CRC_SetPolynomial(POLYNOME);
#endif /* defined (STM32F30X) || defined (STM32F37X) */

#if defined (STM32F0XX)
  /* Init the INIT register */
  CRC_SetInitRegister(INITIAL_CRC_VALUE);
#endif /* defined (STM32F0XX) */
}

/**
  * @brief  Computes the CRC of a given buffer table of 32, 16 or 8 bits data
  * @param  pBuffer: pointer to the constant buffer table
  * @retval CRC computed value of the pBuffer[]
  */
POLYRETURN CRC_CalcBlockCRCxxbits(DATATYPE *Address)
{
  uint32_t windex = 0;

  /* Reset the systick peripheral */
  SYSTICK_RESET;

  /* Set LOAD and CTRL registers of the Systick to the specified values */
  SYSTICK_START;

  /* A loop to compute the CRC of Data Buffer */
  for (windex = LOWER; windex < UPPER; windex = windex + STEP)
  {
    *(__IO DATATYPE*)(CRC_BASE) = *(Address++);
  }

  /* Stop the Systick peripheral */
  SYSTICK_STOP;

  /* Return the content of the CRC Data Register */
  return (POLYRETURN)(CRC->DR);
}

/**
  * @brief  Configure the DMA channel or stream to transfer data from *DataAdr
      to CRC Data Register
  * @param  DataAdr: pointer to the constant buffer table
  * @retval None
  */

void CRC_DMA_Config(uint32_t Address)
{
  DMA_InitTypeDef DMA_InitStruct;
  NVIC_InitTypeDef NVIC_InitStruct;

#if defined(STM32F2XX) || defined (STM32F4XX)
  RCC_AHB1PeriphClockCmd(RCC_AHB1Periph_DMA2, ENABLE);
#else
  RCC_AHBPeriphClockCmd(RCC_AHBPeriph_DMA1, ENABLE);
#endif /* defined(STM32F2XX) || defined (STM32F4XX) */


  DMA_InitStruct.DMA_PeripheralBaseAddr = Address;
#if defined(STM32F2XX) || defined (STM32F4XX)
  DMA_InitStruct.DMA_Channel = DMA_CHANNEL;
  DMA_InitStruct.DMA_DIR = DMA_DIR_MemoryToMemory;
  DMA_InitStruct.DMA_Memory0BaseAddr = CRC_BASE;
  DMA_InitStruct.DMA_FIFOMode = DMA_FIFOMode_Disable;
  DMA_InitStruct.DMA_FIFOThreshold = DMA_FIFOThreshold_Full;
  DMA_InitStruct.DMA_MemoryBurst = DMA_MemoryBurst_Single;
  DMA_InitStruct.DMA_PeripheralBurst = DMA_PeripheralBurst_Single;
#else
  DMA_InitStruct.DMA_M2M = DMA_M2M_Enable;
  DMA_InitStruct.DMA_DIR = DMA_DIR_PeripheralSRC;
  DMA_InitStruct.DMA_MemoryBaseAddr = CRC_BASE;
#endif  /* defined(STM32F2XX) || defined (STM32F4XX) */

  DMA_InitStruct.DMA_BufferSize = BUFFER_SIZE;
  DMA_InitStruct.DMA_PeripheralInc = DMA_PeripheralInc_Enable;
  DMA_InitStruct.DMA_MemoryInc = DMA_MemoryInc_Disable;
  DMA_InitStruct.DMA_PeripheralDataSize = DMAPeripheralTransferSize;
  DMA_InitStruct.DMA_MemoryDataSize = DMAMemoryTransferSize;
  DMA_InitStruct.DMA_Mode = DMA_Mode_Normal;
  DMA_InitStruct.DMA_Priority = DMA_Priority_High;
#if defined(STM32F2XX) || defined (STM32F4XX)
  /* Reset DMA Stream registers */
  DMA_DeInit(DMA_STREAM);
  /* Configure DMA_STREAM */
  DMA_Init(DMA_STREAM, &DMA_InitStruct);
  /* Enable DMA Stream Transfer Complete interrupt */
  DMA_ITConfig(DMA_STREAM, DMA_IT_TC, ENABLE);
#else
  /* Reset DMA Channel registers */
  DMA_DeInit(DMA_CHANNEL);
  /* Configure DMA_CHANNEL */
  DMA_Init(DMA_CHANNEL, &DMA_InitStruct);
  /* Enable DMA Stream Transfer Complete interrupt */
  DMA_ITConfig(DMA_CHANNEL, DMA_IT_TC, ENABLE);
#endif /*  defined(STM32F2XX) || defined (STM32F4XX) */

  /* Enable the DMA Stream or Channel IRQ Channel */
  NVIC_InitStruct.NVIC_IRQChannel = DMA_IRQ;

  /* Define the IRQ Channel priority */
#if defined (STM32F0XX)
  NVIC_InitStruct.NVIC_IRQChannelPriority = 0;
#else
  NVIC_InitStruct.NVIC_IRQChannelPreemptionPriority = 0;
  NVIC_InitStruct.NVIC_IRQChannelSubPriority = 0;
#endif /* defined (STM32F0XX) */

  NVIC_InitStruct.NVIC_IRQChannelCmd = ENABLE;
  NVIC_Init(&NVIC_InitStruct);
}
#ifdef  USE_FULL_ASSERT

/**
  * @brief  Reports the name of the source file and the source line number
  *         where the assert_param error has occurred.
  * @param  file: pointer to the source file name
  * @param  line: assert_param error line source number
  * @retval None
  */
void assert_failed(uint8_t* file, uint32_t line)
{
  /* User can add his own implementation to report the file name and line
   number,
     ex: printf("Wrong parameters value: file %s on line %d\r\n", file, line)
  */

  /* Infinite loop */
  while (1)
  {}
}

#endif
/**
  * @}
  */

/**
  * @}
  */

/*********************** (C) COPYRIGHT STMicroelectronics *****END OF FILE****/
