/**
  ******************************************************************************
  * @file    CRC_usage/inc/main.h
  * @author  MCD Application Team
  * @version V1.0.1
  * @date    21-October-2013
  * @brief   Header for main.c module
  ******************************************************************************
  * @attention
  *
  * <h2><center>&copy; COPYRIGHT 2013 STMicroelectronics</center></h2>
  *
  * Licensed under MCD-ST Liberty SW License Agreement V2, (the "License");
  * You may not use this file except in compliance with the License.
  * You may obtain a copy of the License at:
  *
  *        http://www.st.com/software_license_agreement_liberty_v2
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  * See the License for the specific language governing permissions and
  * limitations under the License.
  *
  ******************************************************************************
  */

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef __MAIN_H
#define __MAIN_H

/* Includes ------------------------------------------------------------------*/
#include "header.h"

/* Exported types ------------------------------------------------------------*/
/* Exported constants --------------------------------------------------------*/
#define SYSTICK_INIT_VALUE 0XFFFFFF
#define SYSTICK_MASK 5
/* Exported macro ------------------------------------------------------------*/
#define SYSTICK_STOP SysTick->CTRL  &= ~(0x1)
#define SYSTICK_START  SysTick->CTRL = 0; \
  SysTick->LOAD = SYSTICK_INIT_VALUE; \
  SysTick->CTRL = SYSTICK_MASK;
/* Exported functions ------------------------------------------------------- */

#if defined (STM32F37X) || defined (STM32F30X)
#if !defined(CONFIGPOLYNOME) || (CONFIGPOLYNOME == 32)
#define POLYSIZE CRC_PolSize_32
#define POLYRETURN uint32_t
#ifndef POLYNOME
#define POLYNOME 0x04C11DB7
#endif
#define INITIAL_CRC_VALUE 0xFFFFFFFF
#define DATA_LENGTH 32
__IO uint32_t Software_ComputedCRC = INITIAL_CRC_VALUE;
#elif (CONFIGPOLYNOME == 16)
#define POLYSIZE CRC_PolSize_16
#define POLYRETURN uint16_t
#ifndef POLYNOME
#define POLYNOME 0x8801
#endif
#define INITIAL_CRC_VALUE 0xFFFF
#define DATA_LENGTH 16
__IO uint16_t Software_ComputedCRC = INITIAL_CRC_VALUE;
#elif (CONFIGPOLYNOME == 8)
#define POLYSIZE CRC_PolSize_8
#define POLYRETURN uint8_t
#ifndef POLYNOME
#define POLYNOME 0xCB
#endif
#define INITIAL_CRC_VALUE 0xFF
#define DATA_LENGTH 8
__IO uint8_t Software_ComputedCRC = INITIAL_CRC_VALUE;
#elif (CONFIGPOLYNOME == 7)
#define POLYSIZE CRC_PolSize_7
#define POLYRETURN uint8_t
#ifndef POLYNOME
#define POLYNOME 0x5B
#endif
#define INITIAL_CRC_VALUE 0xFF
#define DATA_LENGTH 8
__IO uint8_t Software_ComputedCRC = INITIAL_CRC_VALUE;
#endif /* !defined(CONFIGPOLYNOME) || (CONFIGPOLYNOME == 32) */
#else
#define POLYSIZE CRC_PolSize_32
#define POLYNOME 0x04C11DB7
#define POLYRETURN uint32_t
#define INITIAL_CRC_VALUE 0xFFFFFFFF
__IO uint32_t Software_ComputedCRC = INITIAL_CRC_VALUE;
#if !defined(STM32F0XX)
#define DATA_LENGTH 32
#endif
#endif /* defined (STM32F37X) || defined (STM32F30X) */

#if !defined(DATA_LENGTH) || (DATA_LENGTH == 32)
#define DATATYPE uint32_t
#define MSB_MASK 0x80000000
#elif (DATA_LENGTH == 16)
#define DATATYPE uint16_t
#define MSB_MASK 0x8000
#elif (DATA_LENGTH == 8)
#define DATATYPE uint8_t
#define MSB_MASK 0x80
#endif /* !defined(DATA_LENGTH) || (DATA_LENGTH == 32) */

POLYRETURN CrcSoftwareFunc(POLYRETURN Crc, DATATYPE Data, POLYRETURN POLY);

#endif /* __MAIN_H */

/*********************** (C) COPYRIGHT STMicroelectronics *****END OF FILE****/
