/**
  *****************************************************************************
  * @file    CRC_usage/src/main.c
  * @author  MCD Application Team
  * @version V1.0.1
  * @date    21-October-2013
  * @brief   The main program of the CRC usage example
  *****************************************************************************
  * @attention
  *
  * <h2><center>&copy; COPYRIGHT 2013 STMicroelectronics</center></h2>
  *
  * Licensed under MCD-ST Liberty SW License Agreement V2, (the "License");
  * You may not use this file except in compliance with the License.
  * You may obtain a copy of the License at:
  *
  *        http://www.st.com/software_license_agreement_liberty_v2
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  * See the License for the specific language governing permissions and
  * limitations under the License.
  *
  *****************************************************************************
  */

/* Includes -----------------------------------------------------------------*/
#include "main.h"

/** @addtogroup CRC_usage
  * @{
  */

/* Private typedef ----------------------------------------------------------*/
/* Private define -----------------------------------------------------------*/
#define BUFFER_SIZE    256 /* data buffer size */
#define LOWER 0 /* lower limit */
#define UPPER BUFFER_SIZE /* upper limit */
#define STEP 1 /* step size */
#define CRCUPPER sizeof(DATATYPE)*8 /* CRC software upper limit */
#define CRC_SHIFT 1

/* Private macro ------------------------------------------------------------*/
/* Private variables --------------------------------------------------------*/
#if !defined(DATA_LENGTH) || (DATA_LENGTH == 32)
static const DATATYPE DataBuffer[BUFFER_SIZE] =
  {
    0xf541a337, 0x858fee02, 0xc825352a, 0xac009a3f, 0xdbf03085,
    0x99f6aba8, 0xee80134c, 0x553afc95, 0x6a9b9ab8, 0xa07fc191,
    0x51b7562a, 0x4ab111a2, 0x1c66a0e7, 0x2d4c350c, 0x01dd41fd,
    0xb9248a9d, 0xa31db5c4, 0x0f59d6ff, 0x17cffae7, 0xf2f50d57,
    0xea1f93f1, 0x7fa219b5, 0xbecca65c, 0xf0dfad7a, 0x0e05406b,
    0xb9e3140d, 0x1eaf1b6e, 0x71e9b346, 0xe415fe27, 0x7ff61d29,
    0x87d8feba, 0x3bc5d3a1, 0x6fada226, 0xc3c52e8b, 0xa3d3d46a,
    0x042fe8e3, 0xa4bf3777, 0x3a28228a, 0x329370f7, 0x9c9d80dc,
    0x018d99c6, 0x3ab06072, 0xd5d600b9, 0x2164461e, 0xf677ab89,
    0xcca0c1dc, 0x054efa5b, 0x81ef4f82, 0x5c17bbc8, 0x5de636cb,
    0x683e5011, 0x962a387b, 0x680d2963, 0x3f46dce0, 0x1dc813d8,
    0xa0ba210f, 0x5e5ca1db, 0x001fbd53, 0x91db9c95, 0x5bb3ee20,
    0xfca04edf, 0x4e9a9c4b, 0xd75c76cd, 0x0a8f6dc0, 0xd1859c66,
    0x8d06f740, 0x532ca6e8, 0x311a9b88, 0xaa354bba, 0xa62394a0,
    0x2179300d, 0x211686a9, 0xb7ab884f, 0xb344c12c, 0x8efbd720,
    0x296deff7, 0x4d47788a, 0xe96fcca4, 0x6cf201ed, 0xf8f9fcd0,
    0x3e55ea72, 0x13159056, 0xd7467019, 0xef7ea2a7, 0x850dd3fa,
    0x6ff4d6e5, 0x2cd246a5, 0xe4e9a78f, 0x8b0fbb77, 0xe98b9b63,
    0x7543711f, 0x6ab72c98, 0x346d9339, 0xfb2c3a01, 0xdd2ec152,
    0xad9dc926, 0x45018f9b, 0x5c877f4f, 0x77bdce98, 0x8bc82920,
    0x639899b8, 0xf91bb644, 0x5340339e, 0xc1373952, 0xf9d5202a,
    0x6af6c164, 0x2f61ae95, 0x07758ebb, 0x45bbb072, 0xe8c90534,
    0xe402852a, 0xc3b7c079, 0x697cb232, 0x7ba03636, 0x3c94cedc,
    0xcb97cc68, 0x95d06cdc, 0xf12d8b4f, 0x64255d27, 0x51da1480,
    0x78fba20a, 0x08e0ba88, 0x5056482f, 0x2fc9306d, 0xb00263e4,
    0x2b3e8675, 0x1e029c56, 0x30b6f72a, 0x291dc5a0, 0x48b0c7f8,
    0x50d2d68e, 0xb1e2f718, 0xecb5998a, 0x01099f9d, 0xa89d036a,
    0x6e42b99b, 0x1847b177, 0x3f501e17, 0xd224b261, 0x6d541152,
    0x6bc86a65, 0x5ba21d87, 0xc5626ab2, 0xed509625, 0xf326b0a9,
    0x209b70ef, 0x9f1f60fd, 0x5945c096, 0xacad620d, 0x3d722324,
    0x7d32cdcc, 0xba682c72, 0xc384d2ec, 0xc30d5072, 0xb3b181b8,
    0x82831a88, 0xbd60dcba, 0x22e057c3, 0x37750f70, 0xda439614,
    0x120fb776, 0xd8d05bb7, 0x83f9120d, 0x120fb776, 0xd8d05bb7,
    0x166e0e87, 0xbeaea110, 0x4642a9d5, 0x166e0e87, 0xbeaea110,
    0x2a2d0859, 0xa87432ff, 0x2559e8d1, 0x2a2d0859, 0xa87432ff,
    0x5a98b4af, 0xb27bc37a, 0x7c52e799, 0x5a98b4af, 0xb27bc37a,
    0x39529f2c, 0xcf766b4a, 0xc9c38fa3, 0x39529f2c, 0xcf766b4a,
    0xf108f92b, 0xa9e95709, 0xa1b98a2f, 0xf108f92b, 0xa9e95709,
    0xbd41c503, 0x8c95c4b1, 0x3457d705, 0xbd41c503, 0x8c95c4b1,
    0xc7592b96, 0x2e58d9ed, 0x070ad546, 0xc7592b96, 0x2e58d9ed,
    0x1bff004b, 0x56482f9a, 0x6428b4fc, 0x1bff004b, 0x56482f9a,
    0x64a0746f, 0x645a1d25, 0x59463318, 0x64a0746f, 0x645a1d25,
    0x4d67fa8c, 0x22a11da0, 0xfefda36b, 0x4d67fa8c, 0x22a11da0,
    0xde779739, 0xc680c2fc, 0x1eacdebb, 0xde779739, 0xc680c2fc,
    0xdab89df8, 0x232dd821, 0xfac48a2f, 0xdab89df8, 0x232dd821,
    0xc9dbe472, 0xb870085f, 0x12213a95, 0xc9dbe472, 0xb870085f,
    0x05f0bf14, 0x56c4ef3f, 0x777e6f61, 0x05f0bf14, 0x56c4ef3f,
    0x5acf19ad, 0x3ed560d5, 0xc40b85c5, 0x5acf19ad, 0x3ed560d5,
    0x12e30efb, 0xc89dcfc6, 0x640c57c0, 0x12e30efb, 0xc89dcfc6,
    0xf835addf, 0xc24761ac, 0xb471d8ab, 0xf835addf, 0xc24761ac,
    0x7cf18fd7, 0x53b5ccfc, 0x1f0cb91d, 0x7cf18fd7, 0x53b5ccfc,
    0x9398538d
  };
#endif /* !defined(DATA_LENGTH) || (DATA_LENGTH == 32) */
#if (DATA_LENGTH == 16)
static const DATATYPE DataBuffer[BUFFER_SIZE] =
  {
    0x800f, 0x08f5, 0xea30, 0x9cb8, 0xb161, 0xaa1d, 0xd71f, 0xc221,
    0xe70a, 0xa574, 0x6c60, 0xcfe8, 0xcbae, 0x3c29, 0x242f, 0x5d24,
    0xb74a, 0x5291, 0x357e, 0x02fd, 0x9858, 0x27d2, 0x63ea, 0xfd84,
    0xfe33, 0x9cf2, 0x81e9, 0x5212, 0x062e, 0x1e38, 0xc0f9, 0xdd4a,
    0x3c0e, 0x1362, 0xaab3, 0xad5d, 0xae9c, 0xf161, 0xdbd6, 0x10b4,
    0xbbae, 0x4949, 0x6d56, 0xaefb, 0x4384, 0x91b3, 0x64e2, 0x98e8,
    0x335b, 0x056f, 0xa07e, 0x4336, 0x0fb8, 0x1f4a, 0x3590, 0xac21,
    0x9ffc, 0xf37a, 0x7eb0, 0x1e72, 0x2ecb, 0x831d, 0xdf2d, 0xc5d1,
    0xc2b1, 0x4bfb, 0xaf3d, 0x5fdf, 0xb690, 0x1565, 0x2161, 0xcb06,
    0x59b1, 0x609d, 0x5fe5, 0x0c06, 0x4542, 0x7a67, 0x5ce7, 0x094d,
    0xc068, 0xd6c2, 0x4079, 0x9eb7, 0x5cae, 0x75f2, 0x15ba, 0xccf7,
    0xbee7, 0x3e92, 0x1bef, 0x82a6, 0x1b41, 0xe781, 0x9c05, 0xa592,
    0x0e2b, 0xb1bc, 0x9bd8, 0x47ae, 0xe720, 0xd480, 0xe6f7, 0xa8e1,
    0x8b8b, 0x4b06, 0xe183, 0x1867, 0xb658, 0xa2ae, 0x8cb7, 0xdfff,
    0x9db4, 0x0699, 0x5618, 0xccec, 0xf635, 0x5985, 0x33fb, 0x446f,
    0x10e5, 0x22f2, 0x44a2, 0x2c65, 0xdda4, 0x12fc, 0x8936, 0x6c5e,
    0xfa8f, 0xad4a, 0xd840, 0x9f4f, 0x3da7, 0x761c, 0x68b4, 0x9398,
    0x911b, 0x1d80, 0x893c, 0x727a, 0x1bb2, 0xd91d, 0xadf5, 0xbed7,
    0xa3e3, 0x2454, 0xb356, 0x5b1b, 0x3d6d, 0x4950, 0x9cf6, 0x70ac,
    0xd36c, 0x5434, 0xa41f, 0xfe88, 0x87d8, 0xab3f, 0xf12d, 0x9f98,
    0x5040, 0x788c, 0x5171, 0xb053, 0xb95b, 0x0422, 0x0d69, 0x85e4,
    0x08c2, 0x5c5e, 0x3efd, 0xa2e9, 0x8047, 0xa8da, 0xc612, 0xa29a,
    0xce69, 0xbffb, 0x92d4, 0x75c1, 0x2fa0, 0x7c22, 0x8335, 0xa83c,
    0x5ac6, 0x4052, 0xfc63, 0xd02c, 0xd559, 0x5899, 0xa019, 0xb4bd,
    0x2f77, 0xb1df, 0x9509, 0x36d9, 0x07a3, 0x1642, 0x68ae, 0x0c7f,
    0x2674, 0x573a, 0x6b5f, 0xc628, 0x9104, 0x8f4f, 0x1f12, 0xdfaf,
    0x02a6, 0xa0a2, 0xf001, 0x6fef, 0x5a1d, 0xe0f3, 0x14ae, 0xe6c1,
    0x8c18, 0x34b6, 0x24e8, 0x4e5e, 0xce68, 0xceaf, 0x12f3, 0xc37e,
    0x4968, 0x9276, 0x636a, 0x28c5, 0x69ce, 0xaa9c, 0xdf2e, 0xe8dd,
    0x5faa, 0xcffb, 0x899f, 0xe523, 0x59ef, 0xc0bd, 0xb06a, 0xd384,
    0x728a, 0xfe3c, 0x1759, 0xe7bb, 0xc5b7, 0xf0a7, 0xf186, 0xefdd,
    0x6481, 0xe415, 0xd64c, 0xa7f7, 0x4657, 0xf08d, 0xe6cd, 0x820e
  };
#elif (DATA_LENGTH == 8)
static const DATATYPE DataBuffer[BUFFER_SIZE] =
  {
    0x22, 0x32, 0x53, 0xad, 0x76, 0x97, 0x02, 0x07, 0x70, 0xde, 0x73, 0xac,
    0x5b, 0xce, 0xa1, 0x4a, 0xc2, 0xba, 0xd4, 0x74, 0x0c, 0x1d, 0x3b, 0xee,
    0xa8, 0x2f, 0xad, 0xf1, 0xa3, 0x23, 0x80, 0x89, 0x65, 0x3f, 0x29, 0x61,
    0x2f, 0x4f, 0x09, 0x6f, 0x77, 0x59, 0x2e, 0x6b, 0x8f, 0x1a, 0xa8, 0xea,
    0x94, 0x0e, 0x11, 0x05, 0xc9, 0xfe, 0x3b, 0xa8, 0x92, 0xf1, 0xbc, 0x5f,
    0x83, 0xd0, 0x4c, 0xfe, 0x3c, 0x97, 0xde, 0xe6, 0x36, 0x87, 0x83, 0xce,
    0xff, 0x68, 0xb9, 0x5b, 0x66, 0x06, 0xa9, 0x7d, 0x63, 0xbf, 0x08, 0x27,
    0x9d, 0xb8, 0xe3, 0x83, 0xe6, 0x8f, 0xc3, 0xee, 0xe6, 0x91, 0xfe, 0x09,
    0xbf, 0x6c, 0x32, 0x70, 0xc2, 0xb9, 0x8a, 0xf1, 0xc4, 0x21, 0xc4, 0xa9,
    0x4b, 0xd9, 0x01, 0xf7, 0x96, 0xd1, 0x0c, 0x9e, 0xfc, 0x27, 0x57, 0x96,
    0x68, 0xfb, 0xc1, 0xb2, 0x0a, 0x0f, 0x14, 0x98, 0xce, 0x31, 0x0c, 0x81,
    0xae, 0xc1, 0x7d, 0xf3, 0x5f, 0x43, 0x0b, 0x60, 0x49, 0x70, 0xf9, 0xe8,
    0x2f, 0x79, 0xed, 0x28, 0xe9, 0xd6, 0x3b, 0xf5, 0xd4, 0x8c, 0x33, 0xcc,
    0x7b, 0x1c, 0xa5, 0x0c, 0x45, 0x61, 0xe0, 0xb2, 0xcc, 0x31, 0x6e, 0x66,
    0x9f, 0x4a, 0xa7, 0xff, 0xb2, 0x06, 0xac, 0xc1, 0x6c, 0x6c, 0xd4, 0xae,
    0x75, 0xa5, 0x49, 0x69, 0x60, 0x3b, 0x13, 0x80, 0xb8, 0x1f, 0x2c, 0x0d,
    0xdd, 0xe2, 0x82, 0xd3, 0x60, 0x39, 0x97, 0xf8, 0xdc, 0xa5, 0x1d, 0x53,
    0xdd, 0xc8, 0xb0, 0x85, 0xcc, 0xab, 0x56, 0x17, 0x5e, 0x4e, 0x7d, 0xd3,
    0x29, 0x84, 0x86, 0xb3, 0xe6, 0x41, 0x3c, 0x66, 0x14, 0xc4, 0x8e, 0x2c,
    0x6d, 0x2a, 0xd4, 0xb8, 0x0a, 0xb8, 0xc7, 0x4c, 0x4a, 0xc1, 0xb1, 0x7d,
    0xdc, 0xe5, 0x4d, 0x52, 0x00, 0x7d, 0x2b, 0x35, 0xbd, 0x17, 0x79, 0x85,
    0x25, 0x3d, 0x19, 0x1c
  };
#endif /* (DATA_LENGTH == 16) */
__IO POLYRETURN CRCValue = 0;
__IO uint32_t ProcessTimeHard = 0;
__IO uint32_t ProcessTimeSoft = 0;

/* Private function prototypes ----------------------------------------------*/
POLYRETURN CRC_CalcBlockCRCxxbits(const DATATYPE pBuffer[]);
static void CRC_Config(void);
/* Private functions --------------------------------------------------------*/
/**
  * @brief  Main program.
  * @param  None
  * @retval None
  */
int main(void)
{
  uint16_t hindex = 0;
  /*!< At this stage the microcontroller clock setting is already configured,
        this is done through SystemInit() function which is called from startup
        file before to branch to application main.
        To reconfigure the default setting of SystemInit() function, refer to
        system_stm32fxxx.c file
      */

  /* CRC Enable clock and CRC configure */
  CRC_Config();


  /* Compute DataBuffer table CRC by the CRC Peripheral */
  CRCValue = CRC_CalcBlockCRCxxbits(DataBuffer);


  /* Get the systick execution time of the CRC_CalcBlockCRCxxbits function */
  ProcessTimeHard = SYSTICK_INIT_VALUE - (SysTick->VAL);

  /* Set LOAD and CTRL registers of the Systick to the specified values */
  SYSTICK_START;

  /* Compute the DataBuffer table CRC via The C code of the CRC */
  for (hindex = LOWER; hindex < UPPER; hindex = hindex + STEP)
  {
    Software_ComputedCRC = CrcSoftwareFunc(Software_ComputedCRC, DataBuffer[hindex], \
                                           POLYNOME);
  }

  /* Stop the Systick peripheral */
  SYSTICK_STOP;

  /* Get the systick execution time of the CRC_CalcBlockCRCxxbits function */
  ProcessTimeSoft = SYSTICK_INIT_VALUE - (SysTick->VAL);

  /* Infinit loop */
  while (1)
  {}
}
/**
  * @brief  Configure CRC peripheral
  * @param  None
  * @retval None
  */
static void CRC_Config(void)
{

  /* Enable CRC clock */
#if defined (STM32F2XX) || defined (STM32F4XX)
  RCC_AHB1PeriphClockCmd(RCC_AHB1Periph_CRC, ENABLE);
#else
  RCC_AHBPeriphClockCmd(RCC_AHBPeriph_CRC, ENABLE);
#endif /* defined (STM32F2XX) || defined (STM32F4XX) */

#if defined (STM32F30X) || defined (STM32F37X)

  /* DeInit CRC peripheral */
  CRC_DeInit();

  /* Init the INIT register */
  CRC_SetInitRegister(INITIAL_CRC_VALUE);

  /* Select the desired polynomial size */
  CRC_PolynomialSizeSelect(POLYSIZE);

  /* Set the polynomial coefficients */
  CRC_SetPolynomial(POLYNOME);
#endif /* defined (STM32F30X) || defined (STM32F37X) */

#if defined(STM32F0XX)
  /* Init the INIT register */
  CRC_SetInitRegister(INITIAL_CRC_VALUE);
#endif /* defined(STM32F0XX) */
  CRC_ResetDR();
}

/**
  * @brief  Computes the CRC of a given buffer table of 32, 16 or 8 bits data
  * @param  pBuffer: pointer to the constant buffer table
  * @retval CRC computed value of the pBuffer[]
  */
POLYRETURN CRC_CalcBlockCRCxxbits(const DATATYPE pBuffer[])
{
  uint32_t windex = 0;


  /* Set LOAD and CTRL registers of the Systick to the specified values */
  SYSTICK_START;

  /* A loop to compute the CRC of Data Buffer */
  for (windex = LOWER; windex < UPPER; windex = windex + STEP)
  {
    *(__IO DATATYPE*)(CRC_BASE) = (DATATYPE)pBuffer[windex];
  }

  /* Stop the Systick peripheral */
  SYSTICK_STOP;

  /* Return the content of the CRC Data Register */
  return (POLYRETURN)(CRC->DR);
}

/**
  * @brief  Algorithm implementation of the CRC
  * @param  Crc: specifies the previous Crc data
  * @param  Data: specifies the input data
  * @retval Crc: the CRC result of the input data
  */

POLYRETURN CrcSoftwareFunc(POLYRETURN Initial_Crc, DATATYPE Input_Data, POLYRETURN POLY)
{
  uint8_t bindex = 0;
  POLYRETURN Crc = 0;

  /* Initial XOR operation with the previous Crc value */
  Crc = Initial_Crc ^ Input_Data;

  /* The CRC algorithm routine */
  for (bindex = LOWER; bindex < CRCUPPER; bindex = bindex + STEP)
  {
    if (Crc & MSB_MASK)
    {
      Crc = (Crc << CRC_SHIFT) ^ POLY;
    }
    else
    {
      Crc = (Crc << CRC_SHIFT);
    }
  }
  return Crc;
}

#ifdef  USE_FULL_ASSERT

/**
  * @brief  Reports the name of the source file and the source line number
  *         where the assert_param error has occurred.
  * @param  file: pointer to the source file name
  * @param  line: assert_param error line source number
  * @retval None
  */
void assert_failed(uint8_t* file, uint32_t line)
{
  /* User can add his own implementation to report the file name and line
   number,
     ex: printf("Wrong parameters value: file %s on line %d\r\n", file, line) 
  */

  /* Infinite loop */
  while (1)
  {}
}

#endif
/**
  * @}
  */
/******************* (C) COPYRIGHT STMicroelectronics *****END OF FILE****/
